@@ -24,19 +24,19 @@ from spyder.utils.programs import find_program
 
 sys.path.append(osp.realpath(osp.dirname(__file__) + "/.."))
 
-from main import create_app
+from spyder_terminal.server.common import create_app
 
 LOCATION = os.path.realpath(os.path.join(os.getcwd(),
                                          os.path.dirname(__file__)))
 LOCATION_SLASH = LOCATION.replace('\\', '/')
 
 LINE_END = '\n'
-SHELL = '/usr/bin/env bash'
+SHELL = 'bash'
 WINDOWS = os.name == 'nt'
 
 if WINDOWS:
     LINE_END = '\r\n'
-    SHELL = find_program('cmd.exe')
+    SHELL = 'cmd'
 
 
 class TerminalServerTests(testing.AsyncHTTPTestCase):
@@ -118,8 +118,8 @@ class TerminalServerTests(testing.AsyncHTTPTestCase):
             print(msg)
             msg = ''.join(msg.rstrip())
         self.assertTrue(test_msg in msg)
+        yield self.close(sock)
 
-    # @pytest.mark.skipif(os.name == 'nt', reason="It doesn't work on Windows")
     @testing.gen_test
     def test_terminal_closing(self):
         """Test terminal destruction."""
@@ -137,8 +137,10 @@ class TerminalServerTests(testing.AsyncHTTPTestCase):
             sock.write_message(' This shall not work')
         except AttributeError:
             pass
+        yield self.close(sock)
 
     @flaky(max_runs=3)
+    @pytest.mark.timeout(10)
     @testing.gen_test
     def test_terminal_resize(self):
         """Test terminal resizing."""
@@ -167,6 +169,12 @@ class TerminalServerTests(testing.AsyncHTTPTestCase):
 
         expected_size = '(73, 23)'
         msg = ''
+        fail_retry = 50
+        tries = 0
         while expected_size not in msg:
+            if tries == fail_retry:
+                break
             msg = yield sock.read_message()
+            tries += 1
         self.assertIn(expected_size, msg)
+        yield self.close(sock)
